@@ -110,7 +110,7 @@ def prepare_image_entry_dict(image, image_type_id, **_):
     }
 
 
-def validate_images(images_params):
+def validate_images(images_params, use_enrolled_image=False, job_type=None):
     if not images_params:
         raise ValueError("Please ensure that you send through image details")
 
@@ -125,3 +125,18 @@ def validate_images(images_params):
                 raise FileNotFoundError(
                     "No such file or directory %s" % (image["image"])
                 )
+
+    if len(images_params) == 0 or not (
+        has_selfie_image(images_params) or (job_type == 6 and use_enrolled_image)
+    ):
+        raise ValueError("You need to send through at least one selfie image")
+
+
+def has_selfie_image(images_params):
+    found = False
+    for image in images_params:
+        image_type_id = int(image["image_type_id"])
+        if image_type_id == 0 or image_type_id == 2:
+            found = True
+            break
+    return found
